PyBondi
===
A lightweight library for creating event driven systems using the unit of work pattern, pubsub and domain driven desing. 

## Installation
``` bash
pip install pybondi
```

## Introduction

This package provides a framework for modeling complex domains using an event driven architecture and the pub/sub pattern and unit of work.